SimpleAffine

Struct SimpleAffine 

pub struct SimpleAffine<F: OutputType> {
    pub scale: [F; 2],
    pub to_offset: [F; 2],
    /* private fields */
}
This is a simple affine transformation object. Inadvertently it also serves as a type converter F<->I<->i32 It can pan and zoom but not rotate.

Fields

scale: [F; 2]

A zoom scale

to_offset: [F; 2]

The offsets needed to center coordinates of interest on the ‘dest’ coordinate system. i.e. the screen coordinate system.

Implementations

Source

impl<F: OutputType> SimpleAffine<F>

pub fn new<I: InputType>( source_aabb: &Aabb2<F>, dest_aabb: &Aabb2<F>, ) -> Result<Self, BvError>

pub fn reverse_transform<I: InputType>( &self, x: F, y: F, ) -> Result<[I; 2], BvError>

transform from destination coordinate system to source coordinate system

pub fn reverse_transform_x<I: InputType>(&self, x: F) -> Result<I, BvError>

transform from destination coordinate system to source coordinate system

pub fn reverse_transform_y<I: InputType>(&self, y: F) -> Result<I, BvError>

transform from dest coordinate system to source coordinate system

pub fn transform(&self, x: F, y: F) -> [F; 2]

transform from source coordinate system to dest coordinate system

pub fn transform_x(&self, x: F) -> F

transform from source coordinate system to dest coordinate system float x coordinate

pub fn transform_y(&self, y: F) -> F

transform from source coordinate system to dest coordinate system float y coordinate

pub fn transform_i<I: InputType>(&self, point: [I; 2]) -> [F; 2]

transform from source coordinate system to dest coordinate system

pub fn transform_f(&self, point: [F; 2]) -> [F; 2]

transform from source coordinate system to dest coordinate system

pub fn transform_p<I: InputType>(&self, point: &Point<I>) -> [F; 2]

transform from source coordinate system to dest coordinate system

pub fn transform_ix<I: InputType>(&self, x: I) -> F

transform from source coordinate system to dest coordinate system integer x coordinate

pub fn transform_iy<I: InputType>(&self, y: I) -> F

transform from source coordinate system to dest coordinate system integer y coordinate

pub fn transform_fx(&self, x: F) -> F

transform from source coordinate system to destination coordinate system float x coordinate

pub fn transform_fy(&self, y: F) -> F

transform from source coordinate system to destination coordinate system float y coordinate

pub fn zoom(&mut self, f: F)

multiply the scale by a factor f